@@ -15,112 +15,86 @@ use function array_flip;
 use function array_keys;
 use function array_merge;
 use function array_unique;
-use function array_values;
 use function count;
 use function explode;
-use function get_class;
-use function is_array;
 use function is_file;
 use function sort;
-use PHPUnit\Framework\TestCase;
-use PHPUnit\Runner\PhptTestCase;
-use PHPUnit\Util\Test;
 use ReflectionClass;
+use SebastianBergmann\CodeCoverage\Data\ProcessedCodeCoverageData;
+use SebastianBergmann\CodeCoverage\Data\RawCodeCoverageData;
 use SebastianBergmann\CodeCoverage\Driver\Driver;
 use SebastianBergmann\CodeCoverage\Node\Builder;
 use SebastianBergmann\CodeCoverage\Node\Directory;
-use SebastianBergmann\CodeCoverage\StaticAnalysis\CachingFileAnalyser;
+use SebastianBergmann\CodeCoverage\StaticAnalysis\CachingSourceAnalyser;
 use SebastianBergmann\CodeCoverage\StaticAnalysis\FileAnalyser;
-use SebastianBergmann\CodeCoverage\StaticAnalysis\ParsingFileAnalyser;
-use SebastianBergmann\CodeUnitReverseLookup\Wizard;
+use SebastianBergmann\CodeCoverage\StaticAnalysis\ParsingSourceAnalyser;
+use SebastianBergmann\CodeCoverage\Test\Target\MapBuilder;
+use SebastianBergmann\CodeCoverage\Test\Target\Mapper;
+use SebastianBergmann\CodeCoverage\Test\Target\TargetCollection;
+use SebastianBergmann\CodeCoverage\Test\Target\TargetCollectionValidator;
+use SebastianBergmann\CodeCoverage\Test\Target\ValidationResult;
+use SebastianBergmann\CodeCoverage\Test\TestSize\TestSize;
+use SebastianBergmann\CodeCoverage\Test\TestStatus\TestStatus;
 
 /**
  * Provides collection functionality for PHP code coverage information.
+ *
+ * @phpstan-type TestType array{size: string, status: string}
+ * @phpstan-type TargetedLines array<non-empty-string, list<positive-int>>
  */
 final class CodeCoverage
 {
-    private const UNCOVERED_FILES = 'UNCOVERED_FILES';
+    private const string UNCOVERED_FILES = 'UNCOVERED_FILES';
+    private readonly Driver $driver;
+    private readonly Filter $filter;
+    private ?FileAnalyser $analyser                  = null;
+    private ?Mapper $targetMapper                    = null;
+    private ?string $cacheDirectory                  = null;
+    private bool $checkForUnintentionallyCoveredCode = false;
+    private bool $collectBranchAndPathCoverage       = false;
+    private bool $includeUncoveredFiles              = true;
+    private bool $ignoreDeprecatedCode               = false;
+    private bool $useAnnotationsForIgnoringCode      = true;
 
     /**
-     * @var Driver
+     * @var list<class-string>
      */
-    private $driver;
+    private array $parentClassesExcludedFromUnintentionallyCoveredCodeCheck = [];
+    private ?string $currentId                                              = null;
+    private ?TestSize $currentSize                                          = null;
+    private ProcessedCodeCoverageData $data;
 
     /**
-     * @var Filter
+     * @var array<string, TestType>
      */
-    private $filter;
-
-    /**
-     * @var Wizard
-     */
-    private $wizard;
-
-    /**
-     * @var bool
-     */
-    private $checkForUnintentionallyCoveredCode = false;
-
-    /**
-     * @var bool
-     */
-    private $includeUncoveredFiles = true;
-
-    /**
-     * @var bool
-     */
-    private $processUncoveredFiles = false;
-
-    /**
-     * @var bool
-     */
-    private $ignoreDeprecatedCode = false;
-
-    /**
-     * @var PhptTestCase|string|TestCase
-     */
-    private $currentId;
-
-    /**
-     * Code coverage data.
-     *
-     * @var ProcessedCodeCoverageData
-     */
-    private $data;
-
-    /**
-     * @var bool
-     */
-    private $useAnnotationsForIgnoringCode = true;
-
-    /**
-     * Test data.
-     *
-     * @var array
-     */
-    private $tests = [];
-
-    /**
-     * @psalm-var list<class-string>
-     */
-    private $parentClassesExcludedFromUnintentionallyCoveredCodeCheck = [];
-
-    /**
-     * @var ?FileAnalyser
-     */
-    private $analyser;
-
-    /**
-     * @var ?string
-     */
-    private $cacheDirectory;
+    private array $tests             = [];
+    private ?Directory $cachedReport = null;
 
     public function __construct(Driver $driver, Filter $filter)
     {
         $this->driver = $driver;
         $this->filter = $filter;
         $this->data   = new ProcessedCodeCoverageData;
-        $this->wizard = new Wizard;
+    }
+
+    public function __serialize(): array
+    {
+        $prefix = "\x00" . self::class . "\x00";
+
+        return [
+            // Configuration
+            $prefix . 'cacheDirectory'                                           => $this->cacheDirectory,
+            $prefix . 'checkForUnintentionallyCoveredCode'                       => $this->checkForUnintentionallyCoveredCode,
+            $prefix . 'includeUncoveredFiles'                                    => $this->includeUncoveredFiles,
+            $prefix . 'ignoreDeprecatedCode'                                     => $this->ignoreDeprecatedCode,
+            $prefix . 'parentClassesExcludedFromUnintentionallyCoveredCodeCheck' => $this->parentClassesExcludedFromUnintentionallyCoveredCodeCheck,
+            $prefix . 'useAnnotationsForIgnoringCode'                            => $this->useAnnotationsForIgnoringCode,
+            $prefix . 'filter'                                                   => $this->filter,
+
+            // Data
+            $prefix . 'data'  => $this->data,
+            $prefix . 'tests' => $this->tests,
+        ];
     }
 
     /**
@@ -128,7 +102,11 @@ final class CodeCoverage
      */
     public function getReport(): Directory
     {
-        return (new Builder($this->analyser()))->build($this);
+        if ($this->cachedReport === null) {
+            $this->cachedReport = (new Builder($this->analyser()))->build($this);
+        }
+
+        return $this->cachedReport;
     }
 
     /**
@@ -136,9 +114,19 @@ final class CodeCoverage
      */
     public function clear(): void
     {
-        $this->currentId = null;
-        $this->data      = new ProcessedCodeCoverageData;
-        $this->tests     = [];
+        $this->currentId    = null;
+        $this->currentSize  = null;
+        $this->data         = new ProcessedCodeCoverageData;
+        $this->tests        = [];
+        $this->cachedReport = null;
+    }
+
+    /**
+     * @internal
+     */
+    public function clearCache(): void
+    {
+        $this->cachedReport = null;
     }
 
     /**
@@ -155,9 +143,7 @@ final class CodeCoverage
     public function getData(bool $raw = false): ProcessedCodeCoverageData
     {
         if (!$raw) {
-            if ($this->processUncoveredFiles) {
-                $this->processUncoveredFilesFromFilter();
-            } elseif ($this->includeUncoveredFiles) {
+            if ($this->includeUncoveredFiles) {
                 $this->addUncoveredFilesFromFilter();
             }
         }
@@ -174,7 +160,7 @@ final class CodeCoverage
     }
 
     /**
-     * Returns the test data.
+     * @return array<string, TestType>
      */
     public function getTests(): array
     {
@@ -182,61 +168,46 @@ final class CodeCoverage
     }
 
     /**
-     * Sets the test data.
+     * @param array<string, TestType> $tests
      */
     public function setTests(array $tests): void
     {
         $this->tests = $tests;
     }
 
-    /**
-     * Start collection of code coverage information.
-     *
-     * @param PhptTestCase|string|TestCase $id
-     */
-    public function start($id, bool $clear = false): void
+    public function start(string $id, ?TestSize $size = null, bool $clear = false): void
     {
         if ($clear) {
             $this->clear();
         }
 
-        $this->currentId = $id;
+        $this->currentId   = $id;
+        $this->currentSize = $size;
 
         $this->driver->start();
+
+        $this->cachedReport = null;
     }
 
-    /**
-     * Stop collection of code coverage information.
-     *
-     * @param array|false $linesToBeCovered
-     */
-    public function stop(bool $append = true, $linesToBeCovered = [], array $linesToBeUsed = []): RawCodeCoverageData
+    public function stop(bool $append = true, ?TestStatus $status = null, null|false|TargetCollection $covers = null, ?TargetCollection $uses = null): RawCodeCoverageData
     {
-        if (!is_array($linesToBeCovered) && $linesToBeCovered !== false) {
-            throw new InvalidArgumentException(
-                '$linesToBeCovered must be an array or false'
-            );
-        }
-
         $data = $this->driver->stop();
-        $this->append($data, null, $append, $linesToBeCovered, $linesToBeUsed);
 
-        $this->currentId = null;
+        $this->append($data, null, $append, $status, $covers, $uses);
+
+        $this->currentId    = null;
+        $this->currentSize  = null;
+        $this->cachedReport = null;
 
         return $data;
     }
 
     /**
-     * Appends code coverage data.
-     *
-     * @param PhptTestCase|string|TestCase $id
-     * @param array|false                  $linesToBeCovered
-     *
      * @throws ReflectionException
      * @throws TestIdMissingException
      * @throws UnintentionallyCoveredCodeException
      */
-    public function append(RawCodeCoverageData $rawData, $id = null, bool $append = true, $linesToBeCovered = [], array $linesToBeUsed = []): void
+    public function append(RawCodeCoverageData $rawData, ?string $id = null, bool $append = true, ?TestStatus $status = null, null|false|TargetCollection $covers = null, ?TargetCollection $uses = null): void
     {
         if ($id === null) {
             $id = $this->currentId;
@@ -246,6 +217,26 @@ final class CodeCoverage
             throw new TestIdMissingException;
         }
 
+        if ($status === null) {
+            $status = TestStatus::unknown();
+        }
+
+        if ($covers === null) {
+            $covers = TargetCollection::fromArray([]);
+        }
+
+        if ($uses === null) {
+            $uses = TargetCollection::fromArray([]);
+        }
+
+        $size = $this->currentSize;
+
+        if ($size === null) {
+            $size = TestSize::unknown();
+        }
+
+        $this->cachedReport = null;
+
         $this->applyFilter($rawData);
 
         $this->applyExecutableLinesFilter($rawData);
@@ -260,45 +251,38 @@ final class CodeCoverage
             return;
         }
 
-        if ($id !== self::UNCOVERED_FILES) {
-            $this->applyCoversAnnotationFilter(
-                $rawData,
-                $linesToBeCovered,
-                $linesToBeUsed
-            );
-
-            if (empty($rawData->lineCoverage())) {
-                return;
-            }
-
-            $size         = 'unknown';
-            $status       = -1;
-            $fromTestcase = false;
-
-            if ($id instanceof TestCase) {
-                $fromTestcase = true;
-                $_size        = $id->getSize();
-
-                if ($_size === Test::SMALL) {
-                    $size = 'small';
-                } elseif ($_size === Test::MEDIUM) {
-                    $size = 'medium';
-                } elseif ($_size === Test::LARGE) {
-                    $size = 'large';
-                }
-
-                $status = $id->getStatus();
-                $id     = get_class($id) . '::' . $id->getName();
-            } elseif ($id instanceof PhptTestCase) {
-                $fromTestcase = true;
-                $size         = 'large';
-                $id           = $id->getName();
-            }
-
-            $this->tests[$id] = ['size' => $size, 'status' => $status, 'fromTestcase' => $fromTestcase];
-
-            $this->data->markCodeAsExecutedByTestCase($id, $rawData);
+        if ($id === self::UNCOVERED_FILES) {
+            return;
         }
+
+        $linesToBeCovered = false;
+        $linesToBeUsed    = [];
+
+        if ($covers !== false) {
+            $linesToBeCovered = $this->targetMapper()->mapTargets($covers);
+        }
+
+        if ($linesToBeCovered !== false) {
+            $linesToBeUsed = $this->targetMapper()->mapTargets($uses);
+        }
+
+        $this->applyCoversAndUsesFilter(
+            $rawData,
+            $linesToBeCovered,
+            $linesToBeUsed,
+            $size,
+        );
+
+        if ($rawData->lineCoverage() === []) {
+            return;
+        }
+
+        $this->tests[$id] = [
+            'size'   => $size->asString(),
+            'status' => $status->asString(),
+        ];
+
+        $this->data->markCodeAsExecutedByTestCase($id, $rawData);
     }
 
     /**
@@ -307,12 +291,14 @@ final class CodeCoverage
     public function merge(self $that): void
     {
         $this->filter->includeFiles(
-            $that->filter()->files()
+            $that->filter()->files(),
         );
 
         $this->data->merge($that->data);
 
         $this->tests = array_merge($this->tests, $that->getTests());
+
+        $this->cachedReport = null;
     }
 
     public function enableCheckForUnintentionallyCoveredCode(): void
@@ -335,16 +321,6 @@ final class CodeCoverage
         $this->includeUncoveredFiles = false;
     }
 
-    public function processUncoveredFiles(): void
-    {
-        $this->processUncoveredFiles = true;
-    }
-
-    public function doNotProcessUncoveredFiles(): void
-    {
-        $this->processUncoveredFiles = false;
-    }
-
     public function enableAnnotationsForIgnoringCode(): void
     {
         $this->useAnnotationsForIgnoringCode = true;
@@ -366,7 +342,7 @@ final class CodeCoverage
     }
 
     /**
-     * @psalm-assert-if-true !null $this->cacheDirectory
+     * @phpstan-assert-if-true !null $this->cacheDirectory
      */
     public function cachesStaticAnalysis(): bool
     {
@@ -390,7 +366,7 @@ final class CodeCoverage
     {
         if (!$this->cachesStaticAnalysis()) {
             throw new StaticAnalysisCacheNotConfiguredException(
-                'The static analysis cache is not configured'
+                'The static analysis cache is not configured',
             );
         }
 
@@ -398,7 +374,7 @@ final class CodeCoverage
     }
 
     /**
-     * @psalm-param class-string $className
+     * @param class-string $className
      */
     public function excludeSubclassesOfThisClassFromUnintentionallyCoveredCodeCheck(string $className): void
     {
@@ -408,32 +384,35 @@ final class CodeCoverage
     public function enableBranchAndPathCoverage(): void
     {
         $this->driver->enableBranchAndPathCoverage();
+
+        $this->collectBranchAndPathCoverage = true;
     }
 
     public function disableBranchAndPathCoverage(): void
     {
         $this->driver->disableBranchAndPathCoverage();
+
+        $this->collectBranchAndPathCoverage = false;
     }
 
     public function collectsBranchAndPathCoverage(): bool
     {
-        return $this->driver->collectsBranchAndPathCoverage();
+        return $this->collectBranchAndPathCoverage;
     }
 
-    public function detectsDeadCode(): bool
+    public function validate(TargetCollection $targets): ValidationResult
     {
-        return $this->driver->detectsDeadCode();
+        return (new TargetCollectionValidator)->validate($this->targetMapper(), $targets);
     }
 
     /**
-     * Applies the @covers annotation filtering.
-     *
-     * @param array|false $linesToBeCovered
+     * @param false|TargetedLines $linesToBeCovered
+     * @param TargetedLines       $linesToBeUsed
      *
      * @throws ReflectionException
      * @throws UnintentionallyCoveredCodeException
      */
-    private function applyCoversAnnotationFilter(RawCodeCoverageData $rawData, $linesToBeCovered, array $linesToBeUsed): void
+    private function applyCoversAndUsesFilter(RawCodeCoverageData $rawData, array|false $linesToBeCovered, array $linesToBeUsed, TestSize $size): void
     {
         if ($linesToBeCovered === false) {
             $rawData->clear();
@@ -441,13 +420,11 @@ final class CodeCoverage
             return;
         }
 
-        if (empty($linesToBeCovered)) {
+        if ($linesToBeCovered === []) {
             return;
         }
 
-        if ($this->checkForUnintentionallyCoveredCode &&
-            (!$this->currentId instanceof TestCase ||
-            (!$this->currentId->isMedium() && !$this->currentId->isLarge()))) {
+        if ($this->checkForUnintentionallyCoveredCode && !$size->isMedium() && !$size->isLarge()) {
             $this->performUnintentionallyCoveredCodeCheck($rawData, $linesToBeCovered, $linesToBeUsed);
         }
 
@@ -458,25 +435,23 @@ final class CodeCoverage
             $rawData->removeCoverageDataForFile($fileWithNoCoverage);
         }
 
-        if (is_array($linesToBeCovered)) {
-            foreach ($linesToBeCovered as $fileToBeCovered => $includedLines) {
-                $rawData->keepLineCoverageDataOnlyForLines($fileToBeCovered, $includedLines);
-                $rawData->keepFunctionCoverageDataOnlyForLines($fileToBeCovered, $includedLines);
-            }
+        foreach ($linesToBeCovered as $fileToBeCovered => $includedLines) {
+            $rawData->keepLineCoverageDataOnlyForLines($fileToBeCovered, $includedLines);
+            $rawData->keepFunctionCoverageDataOnlyForLines($fileToBeCovered, $includedLines);
         }
     }
 
     private function applyFilter(RawCodeCoverageData $data): void
     {
-        if ($this->filter->isEmpty()) {
-            return;
-        }
-
-        foreach (array_keys($data->lineCoverage()) as $filename) {
-            if ($this->filter->isExcluded($filename)) {
-                $data->removeCoverageDataForFile($filename);
+        if (!$this->filter->isEmpty()) {
+            foreach (array_keys($data->lineCoverage()) as $filename) {
+                if ($this->filter->isExcluded($filename)) {
+                    $data->removeCoverageDataForFile($filename);
+                }
             }
         }
+
+        $data->skipEmptyLines();
     }
 
     private function applyExecutableLinesFilter(RawCodeCoverageData $data): void
@@ -486,9 +461,16 @@ final class CodeCoverage
                 continue;
             }
 
+            $linesToBranchMap = $this->analyser()->analyse($filename)->executableLines();
+
             $data->keepLineCoverageDataOnlyForLines(
                 $filename,
-                $this->analyser()->executableLinesIn($filename)
+                array_keys($linesToBranchMap),
+            );
+
+            $data->markExecutableLineByBranch(
+                $filename,
+                $linesToBranchMap,
             );
         }
     }
@@ -502,7 +484,7 @@ final class CodeCoverage
 
             $data->removeCoverageDataForLines(
                 $filename,
-                $this->analyser()->ignoredLinesFor($filename)
+                $this->analyser()->analyse($filename)->ignoredLines(),
             );
         }
     }
@@ -514,7 +496,7 @@ final class CodeCoverage
     {
         $uncoveredFiles = array_diff(
             $this->filter->files(),
-            $this->data->coveredFiles()
+            $this->data->coveredFiles(),
         );
 
         foreach ($uncoveredFiles as $uncoveredFile) {
@@ -522,36 +504,18 @@ final class CodeCoverage
                 $this->append(
                     RawCodeCoverageData::fromUncoveredFile(
                         $uncoveredFile,
-                        $this->analyser()
+                        $this->analyser(),
                     ),
-                    self::UNCOVERED_FILES
+                    self::UNCOVERED_FILES,
                 );
             }
         }
     }
 
     /**
-     * @throws UnintentionallyCoveredCodeException
-     */
-    private function processUncoveredFilesFromFilter(): void
-    {
-        $uncoveredFiles = array_diff(
-            $this->filter->files(),
-            $this->data->coveredFiles()
-        );
-
-        $this->driver->start();
-
-        foreach ($uncoveredFiles as $uncoveredFile) {
-            if (is_file($uncoveredFile)) {
-                include_once $uncoveredFile;
-            }
-        }
-
-        $this->append($this->driver->stop(), self::UNCOVERED_FILES);
-    }
-
-    /**
+     * @param TargetedLines $linesToBeCovered
+     * @param TargetedLines $linesToBeUsed
+     *
      * @throws ReflectionException
      * @throws UnintentionallyCoveredCodeException
      */
@@ -559,7 +523,7 @@ final class CodeCoverage
     {
         $allowedLines = $this->getAllowedLines(
             $linesToBeCovered,
-            $linesToBeUsed
+            $linesToBeUsed,
         );
 
         $unintentionallyCoveredUnits = [];
@@ -567,20 +531,26 @@ final class CodeCoverage
         foreach ($data->lineCoverage() as $file => $_data) {
             foreach ($_data as $line => $flag) {
                 if ($flag === 1 && !isset($allowedLines[$file][$line])) {
-                    $unintentionallyCoveredUnits[] = $this->wizard->lookup($file, $line);
+                    $unintentionallyCoveredUnits[] = $this->targetMapper->lookup($file, $line);
                 }
             }
         }
 
         $unintentionallyCoveredUnits = $this->processUnintentionallyCoveredUnits($unintentionallyCoveredUnits);
 
-        if (!empty($unintentionallyCoveredUnits)) {
+        if ($unintentionallyCoveredUnits !== []) {
             throw new UnintentionallyCoveredCodeException(
-                $unintentionallyCoveredUnits
+                $unintentionallyCoveredUnits,
             );
         }
     }
 
+    /**
+     * @param TargetedLines $linesToBeCovered
+     * @param TargetedLines $linesToBeUsed
+     *
+     * @return TargetedLines
+     */
     private function getAllowedLines(array $linesToBeCovered, array $linesToBeUsed): array
     {
         $allowedLines = [];
@@ -592,7 +562,7 @@ final class CodeCoverage
 
             $allowedLines[$file] = array_merge(
                 $allowedLines[$file],
-                $linesToBeCovered[$file]
+                $linesToBeCovered[$file],
             );
         }
 
@@ -603,13 +573,13 @@ final class CodeCoverage
 
             $allowedLines[$file] = array_merge(
                 $allowedLines[$file],
-                $linesToBeUsed[$file]
+                $linesToBeUsed[$file],
             );
         }
 
         foreach (array_keys($allowedLines) as $file) {
             $allowedLines[$file] = array_flip(
-                array_unique($allowedLines[$file])
+                array_unique($allowedLines[$file]),
             );
         }
 
@@ -617,40 +587,63 @@ final class CodeCoverage
     }
 
     /**
+     * @param list<string> $unintentionallyCoveredUnits
+     *
      * @throws ReflectionException
+     *
+     * @return list<string>
      */
     private function processUnintentionallyCoveredUnits(array $unintentionallyCoveredUnits): array
     {
         $unintentionallyCoveredUnits = array_unique($unintentionallyCoveredUnits);
-        sort($unintentionallyCoveredUnits);
+        $processed                   = [];
 
-        foreach (array_keys($unintentionallyCoveredUnits) as $k => $v) {
-            $unit = explode('::', $unintentionallyCoveredUnits[$k]);
+        foreach ($unintentionallyCoveredUnits as $unintentionallyCoveredUnit) {
+            $tmp = explode('::', $unintentionallyCoveredUnit);
+
+            if (count($tmp) !== 2) {
+                $processed[] = $unintentionallyCoveredUnit;
 
-            if (count($unit) !== 2) {
                 continue;
             }
 
             try {
-                $class = new ReflectionClass($unit[0]);
+                $class = new ReflectionClass($tmp[0]);
 
                 foreach ($this->parentClassesExcludedFromUnintentionallyCoveredCodeCheck as $parentClass) {
                     if ($class->isSubclassOf($parentClass)) {
-                        unset($unintentionallyCoveredUnits[$k]);
-
-                        break;
+                        continue 2;
                     }
                 }
             } catch (\ReflectionException $e) {
                 throw new ReflectionException(
                     $e->getMessage(),
-                    (int) $e->getCode(),
-                    $e
+                    $e->getCode(),
+                    $e,
                 );
             }
+
+            $processed[] = $tmp[0];
         }
 
-        return array_values($unintentionallyCoveredUnits);
+        $processed = array_unique($processed);
+
+        sort($processed);
+
+        return $processed;
+    }
+
+    private function targetMapper(): Mapper
+    {
+        if ($this->targetMapper !== null) {
+            return $this->targetMapper;
+        }
+
+        $this->targetMapper = new Mapper(
+            (new MapBuilder)->build($this->filter, $this->analyser()),
+        );
+
+        return $this->targetMapper;
     }
 
     private function analyser(): FileAnalyser
@@ -659,18 +652,21 @@ final class CodeCoverage
             return $this->analyser;
         }
 
-        $this->analyser = new ParsingFileAnalyser(
-            $this->useAnnotationsForIgnoringCode,
-            $this->ignoreDeprecatedCode
-        );
+        $sourceAnalyser = new ParsingSourceAnalyser;
 
         if ($this->cachesStaticAnalysis()) {
-            $this->analyser = new CachingFileAnalyser(
+            $sourceAnalyser = new CachingSourceAnalyser(
                 $this->cacheDirectory,
-                $this->analyser
+                $sourceAnalyser,
             );
         }
 
+        $this->analyser = new FileAnalyser(
+            $sourceAnalyser,
+            $this->useAnnotationsForIgnoringCode,
+            $this->ignoreDeprecatedCode,
+        );
+
         return $this->analyser;
     }
 }
