@@ -17,9 +17,9 @@ use TheSeer\Tokenizer\XMLSerializer;
 /**
  * @internal This class is not covered by the backward compatibility promise for phpunit/php-code-coverage
  */
-final class Source
+final readonly class Source
 {
-    private readonly DOMElement $context;
+    private DOMElement $context;
 
     public function __construct(DOMElement $context)
     {
