@@ -1083,8 +1083,6 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
 
         $stub = $this->createStub(Driver::class);
 
-        $stub->method('collectsBranchAndPathCoverage')->willReturn(true);
-
         $stub->method('stop')
             ->willReturn(...$data);
 
@@ -1093,6 +1091,8 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
 
         $coverage = new CodeCoverage($stub, $filter);
 
+        $coverage->enableBranchAndPathCoverage();
+
         $coverage->start(
             'BankAccountTest::testBalanceIsInitiallyZero',
             null,
@@ -1162,8 +1162,6 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
 
         $stub = $this->createStub(Driver::class);
 
-        $stub->method('collectsBranchAndPathCoverage')->willReturn(true);
-
         $stub->method('stop')
             ->willReturn(...$data);
 
@@ -1172,6 +1170,8 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
 
         $coverage = new CodeCoverage($stub, $filter);
 
+        $coverage->enableBranchAndPathCoverage();
+
         $coverage->start(
             'faketest',
             null,
@@ -1472,6 +1472,8 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
 
         $coverage = new CodeCoverage($stub, $filter);
 
+        $coverage->enableBranchAndPathCoverage();
+
         $coverage->start(
             'BankAccountTest::testBalanceIsInitiallyZero',
             null,
@@ -1519,6 +1521,8 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
 
         $coverage = new CodeCoverage($stub, $filter);
 
+        $coverage->enableBranchAndPathCoverage();
+
         $coverage->start(
             'BankAccountTest::testBalanceCannotBecomeNegative2',
         );
