@@ -7,11 +7,14 @@
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
  */
-namespace SebastianBergmann\CodeCoverage\tests\Exception;
+namespace SebastianBergmann\CodeCoverage;
 
+use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\Small;
 use PHPUnit\Framework\TestCase;
-use SebastianBergmann\CodeCoverage\UnintentionallyCoveredCodeException;
 
+#[CoversClass(UnintentionallyCoveredCodeException::class)]
+#[Small]
 final class UnintentionallyCoveredCodeExceptionTest extends TestCase
 {
     public function testCanConstructWithEmptyArray(): void
