@@ -10,14 +10,13 @@
 namespace SebastianBergmann\CodeCoverage\Report;
 
 use ReflectionProperty;
+use SebastianBergmann\CodeCoverage\CodeCoverage;
 use SebastianBergmann\CodeCoverage\TestCase;
 
 final class PhpTest extends TestCase
 {
     protected function tearDown(): void
     {
-        parent::tearDown();
-
         $this->removeTemporaryFiles();
     }
 
@@ -30,7 +29,9 @@ final class PhpTest extends TestCase
 
         $unserialized = require TEST_FILES_PATH . 'tmp/serialized.php';
 
-        $this->assertEquals($coverage, $unserialized);
+        $this->assertInstanceOf(CodeCoverage::class, $unserialized);
+        $this->assertEquals($coverage->getData(), $unserialized->getData());
+        $this->assertEquals($coverage->getTests(), $unserialized->getTests());
     }
 
     public function testPHPSerialisationProducesValidCodeWhenOutputIncludesSingleQuote(): void
@@ -42,7 +43,9 @@ final class PhpTest extends TestCase
 
         $unserialized = require TEST_FILES_PATH . 'tmp/serialized.php';
 
-        $this->assertEquals($coverage, $unserialized);
+        $this->assertInstanceOf(CodeCoverage::class, $unserialized);
+        $this->assertEquals($coverage->getData(), $unserialized->getData());
+        $this->assertEquals($coverage->getTests(), $unserialized->getTests());
     }
 
     public function testCacheDataNeverGetSaved(): void
